## Introduction

MalSearch is a library that allows to collect malware samples from multiple malware databases using their API's. It relies on:

- [Maldatabase](https://maldatabase.com/api-doc.html)
- [MalShare](https://www.malshare.com)
- [Malware Bazaar](https://bazaar.abuse.ch/api)
- [Triage]()
- [VirusShare]()
- [VirusTotal](https://docs.virustotal.com/reference/getting-started)


## Setup

This library is available on [PyPi](https://pypi.python.org/pypi/malsearch/) and can be simply installed using Pip:

```sh
pip install malsearch
```

or

```sh
pip3 install malsearch
```
